"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CacheProcessor = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const the_promise_1 = require("the-promise");
const queryable_scope_builder_1 = require("../../query/queryable-scope-builder");
const compiler_1 = require("@kubevious/kubik/dist/processors/compiler");
const types_1 = require("../target/types");
class CacheProcessor {
    constructor(src, executionContext) {
        this._src = src;
        this._logger = executionContext.logger.sublogger("CacheProcessor");
        this._executionContext = executionContext;
        this._runnable = null;
    }
    prepare() {
        const result = {
            success: false,
            messages: [],
        };
        return this._loadModule()
            .then((runnable) => {
            this._runnable = runnable;
        })
            .then(() => {
            this._validate();
            result.success = result.messages.length == 0;
        })
            .catch((reason) => {
            result.success = false;
            this._addError(result.messages, reason.message);
            // this._logger.info("[prepare] %s", reason);
        })
            .then(() => result);
    }
    _loadModule() {
        return the_promise_1.Promise.resolve().then(() => {
            const compilerValues = {
                namespace: null,
                cache: null,
                values: null
            };
            for (const x of the_lodash_1.default.keys(types_1.TopLevelQuery)) {
                compilerValues[x] = null;
            }
            const compiler = new compiler_1.Compiler(this._src, 'RULE_CACHE', compilerValues);
            return compiler.compile();
        });
    }
    _validate() { }
    execute(namespace, values) {
        const result = {
            success: false,
            messages: [],
            namespace: namespace,
            cache: {}
        };
        return the_promise_1.Promise.resolve()
            .then(() => {
            const valueMap = {
                namespace: namespace,
                cache: result.cache,
                values: values
            };
            this._setupQueryBuilders(valueMap, namespace);
            return this._runnable.run(valueMap);
        })
            .then(() => {
            result.success = true;
        })
            .catch((reason) => {
            result.success = false;
            this._addError(result.messages, reason.message);
            // this._logger.info("[execute] %s", reason);
        })
            .then(() => result);
    }
    _setupQueryBuilders(valueMap, namespace) {
        const rootScopeBuilder = {
            setup: (name, func) => {
                valueMap[name] = func;
            }
        };
        (0, queryable_scope_builder_1.buildQueryableTargetScope)(rootScopeBuilder, namespace, this._executionContext);
    }
    _addError(list, msg) {
        this._logger.info("[RULE ERROR] %s", msg);
        list.push(msg);
    }
}
exports.CacheProcessor = CacheProcessor;
//# sourceMappingURL=processor.js.map