"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.executeScopeQueryCount = exports.executeScopeQuerySingle = exports.executeScopeQueryMany = exports.QueryableK8sTarget = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const fetcher_1 = require("./fetcher");
const k8s_target_builder_1 = require("../compiler/target/k8s-target-builder");
class QueryableK8sTargetBuilder extends k8s_target_builder_1.K8sTargetBuilder {
    many() {
        return executeScopeQueryMany(this._scope, this._executionContext, this._builderContext);
    }
    single() {
        return executeScopeQuerySingle(this._scope, this._executionContext, this._builderContext);
    }
    count() {
        return executeScopeQueryCount(this._scope, this._executionContext, this._builderContext);
    }
}
class QueryableK8sTarget extends k8s_target_builder_1.K8sTarget {
    constructor(scope, executionContext, targetNamespace) {
        super(scope, executionContext);
        this._builderContext = {};
        if (targetNamespace) {
            this._builderContext.namespace = targetNamespace;
        }
    }
    _makeTargetBuilder() {
        return new QueryableK8sTargetBuilder(this._scope, this._executionContext, this._builderContext);
    }
}
exports.QueryableK8sTarget = QueryableK8sTarget;
function executeScopeQueryMany(scope, executionContext, builderContext) {
    scope.finalize();
    const fetcher = new fetcher_1.QueryFetcher(executionContext, scope);
    const result = fetcher.execute(builderContext);
    if (!result.success) {
        return [];
    }
    return result.items;
}
exports.executeScopeQueryMany = executeScopeQueryMany;
function executeScopeQuerySingle(scope, executionContext, builderContext) {
    const items = executeScopeQueryMany(scope, executionContext, builderContext);
    return the_lodash_1.default.head(items);
}
exports.executeScopeQuerySingle = executeScopeQuerySingle;
function executeScopeQueryCount(scope, executionContext, builderContext) {
    const items = executeScopeQueryMany(scope, executionContext, builderContext);
    return items.length;
}
exports.executeScopeQueryCount = executeScopeQueryCount;
//# sourceMappingURL=queryable-k8s-target.js.map